@@ -9,7 +9,8 @@ use base qw{ Astro::Coord::ECI::Sun };
 
 use Carp;
 
-our $VERSION = '0.133_01';
+our $VERSION = '0.100';
+
 
 1;
 
@@ -46,6 +47,7 @@ This class adds no methods.
 
 This class adds no attributes.
 
+
 =head1 SEE ALSO
 
 L<Astro::Coord::ECI::Sun|Astro::Coord::ECI::Sun>
@@ -53,9 +55,7 @@ L<Astro::Coord::ECI::Sun|Astro::Coord::ECI::Sun>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass>,
-L<https://github.com/trwyant/perl-Astro-Coord-ECI/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -63,7 +63,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2025 by Thomas R. Wyant, III
+Copyright (C) 2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
